@@ -12,9 +12,7 @@ os_info = {
         },
         "editor": {
             "file_name": "libglasswall_core2.so",
-            "dependencies": [
-                "libquazip.so.1",
-            ],
+            "dependencies": [],
         },
         "cli": {
             "file_name": [
@@ -24,7 +22,10 @@ os_info = {
             "dependencies": [],
         },
         "rebuild": {
-            "file_name": "libglasswall.classic.so",
+            "file_name": [
+                "libglasswall.classic.so",
+                "libglasswall.classic.pdf.so"
+            ],
             "dependencies": [],
         },
         "security_tagging": {
@@ -35,8 +36,7 @@ os_info = {
                 "libicuuc.so.56",
                 "libQt5Core.so.5",
                 "libQt5Multimedia.so.5",
-                "libQt5XmlPatterns.so.5",
-                "libquazip.so.1"
+                "libQt5XmlPatterns.so.5"
             ],
         },
         "word_search": {
@@ -54,8 +54,7 @@ os_info = {
             "file_name": "glasswall_core2.dll",
             "dependencies": [
                 "Qt5Core.dll",
-                "Qt5Xml.dll",
-                "quazip.dll",
+                "Qt5Xml.dll"
             ],
         },
         "cli": {
@@ -66,7 +65,10 @@ os_info = {
             "dependencies": [],
         },
         "rebuild": {
-            "file_name": "glasswall.classic.dll",
+            "file_name": [
+                "glasswall.classic.dll",
+                "glasswall.classic.pdf.dll"
+            ],
             "dependencies": [],
         },
         "security_tagging": {
@@ -76,8 +78,7 @@ os_info = {
                 "Qt5Gui.dll",
                 "Qt5Xml.dll",
                 "Qt5XmlPatterns.dll",
-                "Qt5Network.dll",
-                "quazip.dll"
+                "Qt5Network.dll"
             ],
         },
         "word_search": {
